Module command

Module command 

Command component — Cmd+K command palette with search, grouped items, and keyboard navigation.

Structs

CommandItem
A single command item in the palette
Props
Command palette rendering properties

Functions

render
Render the command palette
showcase
Showcase the command palette
trigger
Render a trigger button that opens the command palette